==> rpki-validator-app-2.17-sources.jar: net/ripe/rpki/validator/controllers/TrustAnchorsController.scala <==
/**
 * The BSD License
 *
 * Copyright (c) 2010-2012 RIPE NCC
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *   - Neither the name of the RIPE NCC nor the names of its contributors may be
 *     used to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package net.ripe.rpki.validator
package controllers

import scalaz._, Scalaz._
import models._
import lib.Validation._
import net.ripe.rpki.validator.util.TrustAnchorLocator
import net.ripe.rpki.validator.views._
import net.ripe.rpki.commons.validation.ValidationStatus
import scalaz.Success
import net.ripe.rpki.validator.models.TrustAnchor
import scalaz.Failure

trait TrustAnchorsController extends ApplicationController {
  protected def trustAnchors: TrustAnchors
  protected def updateTrustAnchorState(locator: TrustAnchorLocator, enabled: Boolean)
  protected def validatedObjects: ValidatedObjects
  protected def startTrustAnchorValidation(trustAnchors: Seq[String])

  get(s"${Tabs.TrustAnchorsTab.url}") {
    new views.TrustAnchorsView(trustAnchors, validatedObjects.validationStatusCountByTal, messages = feedbackMessages)
  }

  get(s"${Tabs.TrustAnchorMonitorTab.url}/:identifierHash") {
    validateParameter("identifierHash", required(trustAnchorByIdentifierHash)) match {
      case Success(trustAnchor) => {
        new views.TrustAnchorMonitorView(
          ta = trustAnchor,
          trustAnchorValidations = validatedObjects.all.getOrElse(trustAnchor.locator, TrustAnchorValidations()),
          messages = feedbackMessages)
      }
      case Failure(feedbackMessage) =>
        redirectWithFeedbackMessages(s"${Tabs.TrustAnchorsTab.url}", feedbackMessage)
    }
  }

  get(s"${Tabs.TrustAnchorMonitorTab.url}/validation-detail/:identifierHash") {
    val validatedObjectResultsForTa: IndexedSeq[ValidatedObjectResult] = validateParameter("identifierHash", required(trustAnchorByIdentifierHash)) match {
      case Success(trustAnchor) =>  {
        val validatedObjectsForTa = validatedObjects.all.getOrElse(trustAnchor.locator, TrustAnchorValidations(Seq.empty)).validatedObjects
        val records = for {
          validatedObject: ValidatedObject <- validatedObjectsForTa if validatedObject.validationStatus != ValidationStatus.PASSED
        } yield {
          ValidatedObjectResult(trustAnchor.name, validatedObject.uri, validatedObject.validationStatus, validatedObject.checks.filterNot(_.getStatus == ValidationStatus.PASSED))
        }
        records.seq.toIndexedSeq
      }
      case Failure(feedbackMessage) => IndexedSeq.empty
    }

    new ValidationResultsTableData(validatedObjectResultsForTa) {
      override def getParam(name: String) = params(name)
    }
  }

  post(s"${Tabs.TrustAnchorsTab.url}/update") {
    validateParameter("name", required(trustAnchorByName)) match {
      case Success(trustAnchor) =>
        startTrustAnchorValidation(Seq(trustAnchor.name))
        redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Started validation of trust anchor " + trustAnchor.name)))
      case Failure(_) =>
        startTrustAnchorValidation(trustAnchors.all.map(_.name))
        redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Started validation of all trust anchors.")))
    }
  }

  post(s"${Tabs.TrustAnchorsTab.url}/toggle") {
    validateParameter("name", required(trustAnchorByName)) match {
      case Success(trustAnchor) =>
        val enabled = !trustAnchor.enabled
        updateTrustAnchorState(trustAnchor.locator, enabled)
        if (enabled) {
          startTrustAnchorValidation(Seq(trustAnchor.name))
          redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Trust anchor '" + trustAnchor.name + "' has been enabled.")))
        } else {
          redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Trust anchor '" + trustAnchor.name + "' has been disabled.")))
        }
      case Failure(feedbackMessage) =>
        redirectWithFeedbackMessages("/trust-anchors", feedbackMessage)
    }
  }

  private def trustAnchorByIdentifierHash(s: String): Validation[String, TrustAnchor] =
    trustAnchors.all.find(_.identifierHash == s).map(_.success).getOrElse(("No trust anchor with identifier '" + s + "' found").fail)

  private def trustAnchorByName(s: String): Validation[String, TrustAnchor] =
    trustAnchors.all.find(_.name == s).map(_.success).getOrElse(("No trust anchor with name '" + s + "' found").fail)
}

==> rpki-validator-app-2.19-sources.jar: net/ripe/rpki/validator/controllers/TrustAnchorsController.scala <==
/**
 * The BSD License
 *
 * Copyright (c) 2010-2012 RIPE NCC
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *   - Neither the name of the RIPE NCC nor the names of its contributors may be
 *     used to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package net.ripe.rpki.validator
package controllers

import scalaz._, Scalaz._
import models._
import lib.Validation._
import net.ripe.rpki.validator.util.TrustAnchorLocator
import net.ripe.rpki.validator.views._
import net.ripe.rpki.commons.validation.ValidationStatus
import scalaz.Success
import net.ripe.rpki.validator.models.TrustAnchor
import scalaz.Failure

trait TrustAnchorsController extends ApplicationController {
  protected def trustAnchors: TrustAnchors
  protected def updateTrustAnchorState(locator: TrustAnchorLocator, enabled: Boolean)
  protected def validatedObjects: ValidatedObjects
  protected def startTrustAnchorValidation(trustAnchors: Seq[String])

  get(s"${Tabs.TrustAnchorsTab.url}") {
    new views.TrustAnchorsView(trustAnchors, validatedObjects.validationStatusCountByTal, messages = feedbackMessages)
  }

  get(s"${Tabs.TrustAnchorMonitorTab.url}/:identifierHash") {
    validateParameter("identifierHash", required(trustAnchorByIdentifierHash)) match {
      case Success(trustAnchor) => {
        new views.TrustAnchorMonitorView(
          ta = trustAnchor,
          trustAnchorValidations = validatedObjects.all.getOrElse(trustAnchor.locator, TrustAnchorValidations()),
          messages = feedbackMessages)
      }
      case Failure(feedbackMessage) =>
        redirectWithFeedbackMessages(s"${Tabs.TrustAnchorsTab.url}", feedbackMessage)
    }
  }

  get(s"${Tabs.TrustAnchorMonitorTab.url}/validation-detail/:identifierHash") {
    val validatedObjectResultsForTa: IndexedSeq[ValidatedObjectResult] = getValidatedObjectResultsForTa { status =>
      status != ValidationStatus.PASSED && status != ValidationStatus.FETCH_ERROR
    }

    new ValidationResultsTableData(validatedObjectResultsForTa) {
      override def getParam(name: String) = params(name)
    }
  }

  get(s"${Tabs.TrustAnchorMonitorTab.url}/fetch-detail/:identifierHash") {
    val validatedObjectResultsForTa: IndexedSeq[ValidatedObjectResult] = getValidatedObjectResultsForTa { status => status == ValidationStatus.FETCH_ERROR }

    new FetchResultsTableData(validatedObjectResultsForTa) {
      override def getParam(name: String) = params(name)
    }
  }

  private def getValidatedObjectResultsForTa(filter: ValidationStatus => Boolean) = {
    validateParameter("identifierHash", required(trustAnchorByIdentifierHash)) match {
      case Success(trustAnchor) =>  {
        val validatedObjectsForTa = validatedObjects.all.getOrElse(trustAnchor.locator, TrustAnchorValidations(Seq.empty)).validatedObjects
        val records = for {
          validatedObject: ValidatedObject <- validatedObjectsForTa if filter(validatedObject.validationStatus)
        } yield {
          ValidatedObjectResult(trustAnchor.name, validatedObject.uri, validatedObject.validationStatus, validatedObject.checks.filter(check => filter(check.getStatus)))
        }
        records.seq.toIndexedSeq
      }
      case Failure(feedbackMessage) => IndexedSeq.empty
    }
  }

  post(s"${Tabs.TrustAnchorsTab.url}/update") {
    validateParameter("name", required(trustAnchorByName)) match {
      case Success(trustAnchor) =>
        startTrustAnchorValidation(Seq(trustAnchor.name))
        redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Started validation of trust anchor " + trustAnchor.name)))
      case Failure(_) =>
        startTrustAnchorValidation(trustAnchors.all.map(_.name))
        redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Started validation of all trust anchors.")))
    }
  }

  post(s"${Tabs.TrustAnchorsTab.url}/toggle") {
    validateParameter("name", required(trustAnchorByName)) match {
      case Success(trustAnchor) =>
        val enabled = !trustAnchor.enabled
        updateTrustAnchorState(trustAnchor.locator, enabled)
        if (enabled) {
          startTrustAnchorValidation(Seq(trustAnchor.name))
          redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Trust anchor '" + trustAnchor.name + "' has been enabled.")))
        } else {
          redirectWithFeedbackMessages("/trust-anchors", Seq(InfoMessage("Trust anchor '" + trustAnchor.name + "' has been disabled.")))
        }
      case Failure(feedbackMessage) =>
        redirectWithFeedbackMessages("/trust-anchors", feedbackMessage)
    }
  }

  private def trustAnchorByIdentifierHash(s: String): Validation[String, TrustAnchor] =
    trustAnchors.all.find(_.identifierHash == s).map(_.success).getOrElse(("No trust anchor with identifier '" + s + "' found").fail)

  private def trustAnchorByName(s: String): Validation[String, TrustAnchor] =
    trustAnchors.all.find(_.name == s).map(_.success).getOrElse(("No trust anchor with name '" + s + "' found").fail)
}
